@@ -1,5 +1,6 @@
 CAL_START = "CAL_START"
 CAL_END = "CAL_END"
+ENABLE_1D_LUT = "1D_DPG_EN"
 GET_1D_LUT = "GET_1D_DPG_DATA"
 UPLOAD_1D_LUT = "1D_DPG_DATA"
 GET_3D_LUT = "GET_3D_LUT_DATA"
@@ -13,6 +14,7 @@ GET_GAMMA_2_2_TRANSFORM = "GET_1D_2_2_EN"
 ENABLE_GAMMA_2_2_TRANSFORM = "1D_2_2_EN"
 GET_GAMMA_0_45_TRANSFORM = "GET_1D_0_45_EN"
 ENABLE_GAMMA_0_45_TRANSFORM = "1D_0_45_EN"
+ENABLE_3BY3_GAMUT = "3BY3_GAMUT_EN"
 GET_3BY3_GAMUT_DATA = "GET_3BY3_GAMUT_DATA"
 BT709_3BY3_GAMUT_DATA = "BT709_3BY3_GAMUT_DATA"
 BT2020_3BY3_GAMUT_DATA = "BT2020_3BY3_GAMUT_DATA"
